@@ -16,7 +16,7 @@ limitations under the License.
 
 package kustomization
 
-import "sigs.k8s.io/kustomize/api/filesys"
+import "sigs.k8s.io/kustomize/kyaml/filesys"
 
 type Options struct {
 	FileSystem filesys.FileSystem
